@@ -6,16 +6,17 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.server.hooksmanager import Hook
-
+from cubicweb.server.hook import Hook
+from cubicweb.selectors import implements
 
 class AddUpdateTagHook(Hook):
     """ensure tag names are lower case and commas are forbidden"""
+    __regid__ = 'add_update_tag'
     events = ('before_add_entity', 'before_update_entity',)
-    accepts = ('Tag',)
+    __select__ = Hook.__select__ & implements('Tag')
 
-    def call(self, session, entity):
-        if 'name' in entity:
-            name = entity['name'].lower()
+    def __call__(self):
+        if 'name' in self.entity:
+            name = self.entity['name'].lower()
             name = ' - '.join(part.strip() for part in name.split(','))
-            entity['name'] = name
+            self.entity['name'] = name
