@@ -1,5 +1,6 @@
+from yams.buildobjs import EntityType, String, SubjectRelation, RelationType
 
-class Tag(MetaUserEntityType):
+class Tag(EntityType):
     """tags are used by users to mark entities.
     When you include the Tag entity, all application specific entities
     may then be tagged using the "tags" relation.
@@ -10,5 +11,5 @@ class Tag(MetaUserEntityType):
     # should be taggeable
     tags = SubjectRelation('Tag', description=_("tagged objects"))
 
-class tags(MetaUserRelationType):
+class tags(RelationType):
     """indicates that an entity is classified by a given tag"""
